@@ -1,2 +1,4 @@
 """In this module you will find Pane extensions to Panel. For example the PandasProfileReport"""
+from .code import Code
+from .model_viewer import ModelViewer
 from .pandas_profile_report import PandasProfileReport
